==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/sn_blog.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_sn.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_blog'] = 							"journal";
$lang['hdr_blog_entries'] = 					"journal entries";
$lang['hdr_related_blogs'] = 					"related journals";


//A HREF TAGS (links)
$lang['href_recommend_this'] = 					"recommend this";
$lang['href_unrecommend_this'] =				"remove recommendation";
$lang['href_unwatch_this'] =					"remove favourite";
$lang['href_watch_this'] =						"add to my favourites";
?>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/sn_blog.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//HEADER
$lang['hdr_blog'] = 							"blog";
$lang['hdr_blog_entries'] = 					"blog entries";
$lang['hdr_blog_history'] = 					"blog history";


//A HREF TAGS (links)
$lang['href_recommend_this'] = 					"tip this";
$lang['href_unrecommend_this'] =				"remove tip";
$lang['href_unwatch_this'] =					"remove mark";
$lang['href_watch_this'] =						"add mark";
$lang['href_add_blog'] = 						"add blog";
$lang['href_latest_blog'] = 					"latest blogs";
$lang['href_comments'] = 						"comments";
$lang['href_blog_history'] = 					"blog history";

// BODY
$lang['txt_blog'] = 							"blog";//breadcrumb

?>
